/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package transaction.entity;

import javax.ejb.CreateException;

import transaction.interfaces.BankData;
import transaction.interfaces.BankPK;

/**
 * The Session bean represents a bank.
 *
 * @author Andreas Schaefer
 * @version $Revision: 1.1 $
 *
 * @ejb:bean name="bank/Bank"
 *           display-name="Bank Entity"
 *           type="CMP"
 *           view-type="remote"
 *           jndi-name="ejb/bank/Bank"
 *           schema="Bank"
 *
 * @ejb:interface extends="javax.ejb.EJBObject"
 *
 * @ejb:home extends="javax.ejb.EJBHome"
 *
 * @ejb:pk extends="java.lang.Object"
 *
 * @ejb:data-object extends="java.lang.Object"
 *                  generate="true"
 *
 * @ejb:finder signature="java.util.Collection findAll()"
 *             query="SELECT OBJECT(o) FROM Bank AS o"
 *
 * @ejb:transaction type="Required"
 *
 * @jboss:table-name table-name="New_Bank"
 *
 * @jboss:create-table create="true"
 *
 * @jboss:remove-table remove="true"
 */
public abstract class BankBean
   extends EntitySupport
{
   // Constants -----------------------------------------------------
   
   // Attributes ----------------------------------------------------
   
   // Static --------------------------------------------------------
   
   // Constructors --------------------------------------------------
   
   // Public --------------------------------------------------------
   
   /**
    * @ejb:persistent-field
    * @ejb:pk-field
    *
    * @jboss:column-name name="Id"
    **/
   public abstract String getId();
   
   public abstract void setId( String pId );
   
   /**
    * @ejb:persistent-field
    *
    * @jboss:column-name name="Name"
    **/
   public abstract String getName();
   
   public abstract void setName( String pName );
   
   /**
    * @ejb:persistent-field
    *
    * @jboss:column-name name="Address"
    **/
   public abstract String getAddress();
   
   public abstract void setAddress( String pAddress );
   
   /**
    * @ejb:interface-method view-type="remote"
    **/
   public abstract void setData( BankData pData );
   
   /**
    * @ejb:interface-method view-type="remote"
    **/
   public abstract BankData getData();
   
   // EntityBean implementation -------------------------------------
   
   /**
    * @ejb:create-method view-type="remote"
    **/
   public BankPK ejbCreate( String pName, String pAddress ) 
      throws CreateException
   { 
      setId( "Bank ( " + System.currentTimeMillis() + " )" );
      setName( pName );
      setAddress( pAddress );
      
      return null;
   }
   
   public void ejbPostCreate( String pName, String pAddress ) 
      throws CreateException
   { 
   }
}
